# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/sni_cluster/v3/sni_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/filters/network/sni_cluster/v3/sni_cluster.proto\x12/envoy.extensions.filters.network.sni_cluster.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"J\n\nSniCluster:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.network.sni_cluster.v2.SniClusterB\xc0\x01\n=io.envoyproxy.envoy.extensions.filters.network.sni_cluster.v3B\x0fSniClusterProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_cluster/v3;sni_clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.sni_cluster.v3.sni_cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.filters.network.sni_cluster.v3B\017SniClusterProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_cluster/v3;sni_clusterv3\272\200\310\321\006\002\020\002'
  _SNICLUSTER._options = None
  _SNICLUSTER._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.network.sni_cluster.v2.SniCluster'
  _globals['_SNICLUSTER']._serialized_start=184
  _globals['_SNICLUSTER']._serialized_end=258
# @@protoc_insertion_point(module_scope)
